==> roltrilinos-0.0.1.tar.gz: roltrilinos-0.0.1/packages/rol/src/compatibility/teuchos/parameterlist/ROL_ParameterList.hpp <==
// @HEADER
// ************************************************************************
//
//               Rapid Optimization Library (ROL) Package
//                 Copyright (2014) Sandia Corporation
//
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
// 1. Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
//
// 3. Neither the name of the Corporation nor the names of the
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY SANDIA CORPORATION "AS IS" AND ANY
// EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
// PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL SANDIA CORPORATION OR THE
// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
// PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
// LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
// NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
// Questions? Contact lead developers:
//              Drew Kouri   (dpkouri@sandia.gov) and
//              Denis Ridzal (dridzal@sandia.gov)
//
// ************************************************************************
// @HEADER

#pragma once
#include "ROL_SharedPointer.hpp"
#include "Teuchos_ParameterList.hpp"
#include "Teuchos_XMLParameterListCoreHelpers.hpp"

namespace ROL {
using ParameterList = Teuchos::ParameterList;

inline
void readParametersFromXml( const std::string &filename,
                            ParameterList& parlist ) {
  Teuchos::Ptr<ParameterList> p{&parlist};
  Teuchos::updateParametersFromXmlFile( filename, p );
}

  inline void writeParameterListToXmlFile( ParameterList& parlist,
                                           const std::string& filename ) {
    Teuchos::writeParameterListToXmlFile(parlist, filename);
  }

  inline void updateParametersFromXmlFile(const std::string& filename ,
                                          ParameterList& parlist) {
    Teuchos::Ptr<ParameterList> p{&parlist};
    Teuchos::updateParametersFromXmlFile( filename, p );
  }



inline
ROL::SharedPointer<ParameterList> getParametersFromXmlFile( const std::string& filename )
  {
    auto parlist = ROL::makeShared<ParameterList>();
    Teuchos::Ptr<ParameterList> p{&*parlist};
    Teuchos::updateParametersFromXmlFile( filename, p );
    return parlist;
  }


template <class T>
inline std::vector<T> getArrayFromStringParameter( const ParameterList& parlist,
                                                  const std::string& name ) {
  auto teuchos_arr = Teuchos::getArrayFromStringParameter<T>( parlist, name );

    return teuchos_arr.toVector();
}


} // namespace ROL

==> roltrilinos-0.0.8.tar.gz: roltrilinos-0.0.8/packages/rol/src/compatibility/teuchos/parameterlist/ROL_ParameterList.hpp <==
// @HEADER
// ************************************************************************
//
//               Rapid Optimization Library (ROL) Package
//                 Copyright (2014) Sandia Corporation
//
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
// 1. Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
//
// 3. Neither the name of the Corporation nor the names of the
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY SANDIA CORPORATION "AS IS" AND ANY
// EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
// PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL SANDIA CORPORATION OR THE
// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
// PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
// LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
// NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
// Questions? Contact lead developers:
//              Drew Kouri   (dpkouri@sandia.gov) and
//              Denis Ridzal (dridzal@sandia.gov)
//
// ************************************************************************
// @HEADER

#pragma once
#include "ROL_Ptr.hpp"
#include "Teuchos_ParameterList.hpp"
#include "Teuchos_XMLParameterListCoreHelpers.hpp"

namespace ROL {
using ParameterList = Teuchos::ParameterList;

inline
void readParametersFromXml( const std::string &filename,
                            ParameterList& parlist ) {
  Teuchos::Ptr<ParameterList> p{&parlist};
  Teuchos::updateParametersFromXmlFile( filename, p );
}

  inline void writeParameterListToXmlFile( ParameterList& parlist,
                                           const std::string& filename ) {
    Teuchos::writeParameterListToXmlFile(parlist, filename);
  }

  inline void updateParametersFromXmlFile(const std::string& filename ,
                                          ParameterList& parlist) {
    Teuchos::Ptr<ParameterList> p{&parlist};
    Teuchos::updateParametersFromXmlFile( filename, p );
  }



inline
ROL::Ptr<ParameterList> getParametersFromXmlFile( const std::string& filename )
  {
    auto parlist = ROL::makePtr<ParameterList>();
    Teuchos::Ptr<ParameterList> p{&*parlist};
    Teuchos::updateParametersFromXmlFile( filename, p );
    return parlist;
  }


template <class T>
inline std::vector<T> getArrayFromStringParameter( const ParameterList& parlist,
                                                  const std::string& name ) {
  auto teuchos_arr = Teuchos::getArrayFromStringParameter<T>( parlist, name );

    return teuchos_arr.toVector();
}


} // namespace ROL
